@@ -37,7 +37,7 @@ HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTIO
 CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
 OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  
-$Id: combroyden2.c 2120 2013-01-03 05:17:21Z beerli $
+$Id: combroyden2.c 2169 2013-08-24 19:02:04Z beerli $
  
 -------------------------------------------------------*/
 
@@ -312,17 +312,14 @@ estimateParameter (long rep, long G, world_fmt * world, option_fmt * options,
 MYREAL
 calc_loci_like (helper_fmt * helper, MYREAL *param, MYREAL *lparam)
 {
-#ifndef MPI
-    long locus;
-    MYREAL *mu_rates = helper->nr->world->options->mu_rates;
-#endif
-
     nr_fmt *nr = helper->nr;
     world_fmt *world = helper->nr->world;
     MYREAL logres = 0;
-
-    MYREAL * locusweight = nr->world->data->locusweight;
-
+#ifndef MPI
+    long locus;
+    MYREAL *mu_rates = world->options->mu_rates;
+    MYREAL * locusweight = world->data->locusweight;
+#endif
     if (helper->multilocus)
     {
 #ifdef MPI
