@@ -31,7 +31,7 @@ HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTIO
 CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
 OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  
-$Id: data.c 2169 2013-08-24 19:02:04Z beerli $
+$Id: data.c 2172 2013-10-30 17:50:08Z beerli $
 
 -----------------------------------
 add this to the microsatellite data, this will allow to use
@@ -1249,7 +1249,7 @@ read_popheader (FILE * infile, data_fmt * data, option_fmt * options, long pop,
 		  {
 		    minlength = strlen(input);
 		    minlength = MIN(minlength,80);
-		    sprintf(data->popnames[pop],"%-*s",(int) minlength,input);
+		    sprintf(data->popnames[pop],"%-*.*s",(int) minlength,(int) minlength,input);
 		  }
                 break;//this leaves the numind empty of not specified, the must be filled in later
 	      }
